pub fn encrypt(plain: &[u8], key: &[u8; 32], aad: &[u8]) -> Result<String>
Encrypt plain under key with aad, returning the SOPS value string.
plain
key
aad
Returns the empty string when plain is empty (matching SOPS isEmpty).
isEmpty